@@ -124,6 +124,27 @@ class StorageT(object):
         """
         ...
 
+    @abc.abstractmethod
+    def getObject(self, key, bucket=None, **kwargs):
+        """Gets data from offset to length of an object.
+
+        Arguments:
+            key: Object name in the bucket.
+            bucket: Name of the bucket.
+        """
+        ...
+
+    @abc.abstractmethod
+    def putObject(self, key, data, bucket=None, **kwargs):
+        """Uploads data from a stream to an object in a bucket.
+
+        Arguments:
+            key: Object name in the bucket.
+            data: A string object.
+            bucket: Name of the bucket.
+        """
+        ...
+
     @property
     def appStoreKey(self):
         return self.storagePathJoin("studio", g.userId, g.appId)
@@ -164,6 +185,9 @@ class StorageT(object):
     def componentsStoreKey(self):
         return self.storagePathJoin("studio", g.userId, "component")
 
+    def getKeyInGlobalStore(self, *paths):
+        return self.storagePathJoin("studio", "global", *paths)
+
     def getKeyInAppStore(self, *paths):
         return self.storagePathJoin(self.appStoreKey, *paths)
 
